;
;                                 SuperNova
;                        SDK Version 0.90 - March 1997
;                               Copyright 1997
;                    Jonathan Chang - coder@geocities.com
;                     David Chen - shiitake@geocities.com
;                     Alan Dang - grayghost@geocities.com
;

;
; #DEFINEs for Relative CALLs, JUMPs and System Functions
;
#DEFINE ROM_CALL(index)           call $8C09 \ .db index
#DEFINE CALL_Z(addr)              call $8C0C \ .dw addr
#DEFINE CALL_(addr)               call $8C0F \ .dw addr
#DEFINE CALL_NZ(addr)             call $8C12 \ .dw addr
#DEFINE CALL_C(addr)              call $8C18 \ .dw addr
#DEFINE CALL_NC(addr)             call $8C1E \ .dw addr
#DEFINE JUMP_Z(addr)              call $8C24 \ .dw addr
#DEFINE JUMP_(addr)               call $8C27 \ .dw addr
#DEFINE JUMP_NZ(addr)             call $8C2A \ .dw addr
#DEFINE JUMP_C(addr)              call $8C30 \ .dw addr
#DEFINE JUMP_NC(addr)             call $8C36 \ .dw addr
#DEFINE CALL_LIB(lib,func)        call $8C41 \ .db lib \ .db func
#DEFINE LD_IFACE(init,draw,main)  call $91A9 \ .dw init \ .dw draw \ .dw main
#DEFINE LD_PLUGIN(handler,plugin) call $8E0C \ .dw handler \ .dw plugin
#DEFINE RE_CALC                   ld hl,SN_BITS \ set 0,(hl)
#DEFINE WARP_OUT                  ld hl,SN_BITS \ set 1,(hl)

;
; SuperNova Specific Data Areas
;
PROGRAM_ADDR    =$8C3C  ; Program Address
ROM_VERS	=$8C3E	; ROM version byte
SNOVA_VER       =$8C3F  ; ZShell version number
SN_BITS         =$8C40  ; Bit 0 Set : Recalculate Checksum
                        ; Bit 1 Set : Warp Out to TI Homescreen
ZSHELL_VER      =$8C3F  ; Left this here to preserve ZShell Compatibility
ZS_BITS         =$8C40  ; Left this here to preserve ZShell Compatibility
VAT_NAME        =$8C68  ; Name of entry in VAT
VAT_TYPE        =$8C71  ; Type of entry in VAT
VAT_SIZE        =$8C72  ; Size of entry in VAT
PLUGIN_CALL     =$8CE4  ; Address called by GET_KEY to run Plug-Ins

;
; SuperNova Customizable Interface Specific Data Areas
;
IFACE           =$8D7B  ; Pointers to the areas of the SNova interface file
PROG_NUM        =$8D81  ; Number of programs strings found * 2
SEARCH_START    =$8D83  ; Byte defining which program will be displayed first
SEARCH_COUNT    =$8D85  ; Byte defining number of strings to be displayed
FOUND_ADDR      =$8D87  ; Pointer to current string entry
IFACE_MEM       =$8D9C  ; 12 bytes that can be used for temporary data storage

;
; SuperNova Specific Call Addresses 
; There is no need to use the ROM_CALL function for any of the following.
; Instead, use CALL [FUNCTION]  Example: CALL ERROR_CALL
;
ERROR_CALL      =$8C67  ; Plug-In Return Handler
STRING_COMP     =$8CA1  ; Compare strings & set flags. HL=STRING1 DE=STRING2
SEARCH_VAT      =$8C74  ; Search VAT. Updates VAT_NAME, VAT_TYPE & VAT_SIZE
SEARCH_VAR      =$8CB3  ; Function to search for variables in VAT
GET_KEY         =$8CE0  ; Get key press into %A and allow plugins to be run
CURR_ADDR       =$8CE7  ; Returns absolute address of the next command in HL

;
; SuperNova Customizable Interface Specific Call Addresses 
; There is no need to use the ROM_CALL function for any of the following.
; Instead, use CALL [FUNCTION]  Example: CALL ERROR_CALL
;
RUN_IT          =$8D89  ; Runs a program pointed to by DE * 2 in TEXT_MEM
REFRESH         =$8EE2  ; Searches VAT for valid strings and displays them

;
; Direct System Call addresses
; There is no need to use the ROM_CALL function for any of the following.
; Instead, use CALL [FUNCTION]  Example: CALL LD_HL_MHL
;
LD_HL_MHL       =$0033  ; HL=(HL), A=L
CP_HL_DE        =$008E  ; CP HL,DE (modifies flags only)
UNPACK_HL       =$009A  ; Unpacks one digit of HL into %A
STORE_KEY       =$01B1  ; Store immediate keystroke from %A
GET_KEY2        =$01BE  ; Get immediate keystroke into %A

;
; ROM_CALL System Indexes
; These indexes are used in the ROM_CALL macro to call functions that
; are in the TI-85's ROM.
;
TX_CHARPUT      =$00   ; Translated display of %A on screen, text style
D_LT_STR        =$01   ; Display length-byte normal text string
M_CHARPUT       =$02   ; Display %A on screen, menu style
D_ZM_STR        =$03   ; Display zero-terminated string,  menu style
D_LM_STR        =$04   ; Display length-byte string, menu style
GET_T_CUR       =$05   ; HL = absolute address of text cursor
SCROLL_UP       =$06   ; Scroll text screen up
TR_CHARPUT      =$07   ; Raw display of %A on screen, normal text style
CLEARLCD        =$08   ; Clear LCD, but not text or graphics memory
D_HL_DECI       =$09   ; Disp. HL as 5-byte, right just., blank-pad. decimal
CLEARTEXT       =$0A   ; Clear LCD and text memory (affected by 1,(IY+13))
D_ZT_STR        =$0B   ; Display zero-terminated normal text string
BUSY_OFF        =$0C   ; Turn off "busy" indicataor
BUSY_ON         =$0D   ; Turn on "busy" indicator
FIND_PIXEL      =$80   ; Find location in RAM for a pixel on the GFX screen
                       ; Page must be set to 4 before function is called!
                       ; This can be set using ld a,4 / out (5),a
RANDOMIZE       =$0E   ; Generates a random number in OP1
D_STR_HL        =$0F   ; Display Z-Terminated String pointed by HL at 0,0
CL_ENDLINE      =$10   ; Prints $20 from Cursor Loc to end of line    
RESET_RAND      =$11   ; Reset Random Number Seed
HLX10           =$40   ; HL = HL * 10
ZERO_BYTES      =$41   ; Zero B bytes at HL
MULT_HL         =$42   ; HL = H * L
MSR_STRLN       =$43   ; Measure length of Z-Terminated string
LNSTR_COMP      =$44   ; Length indexed string compare

;
; Data Locations
;
KEY_0           =$8000  ; Translated scancode of last key, but 0 if gotten
KEY_1           =$8001  ; Translated scancode of current key being held down
KEY_2           =$8002  ; Same as KEY_1, but $FF if more than one key is down
KEY_STAT        =$8004  ; Bit 2 set = Key is being held down
LAST_KEY        =$8006  ; Translated scancode of last key pressed
CONTRAST        =$8007  ; Contrast Level (0-31)
CURSOR_ROW      =$800C  ; Current position of text cursor row (0-7)
CURSOR_COL      =$800D  ; Current position of text cursor column (0-21)
CURSOR_ROW2     =$800C  ; Current position of text cursor row (0-7)
CURSOR_COL2     =$800D  ; Current position of text cursor column (0-21)
CURSOR_LET      =$800E  ; Letter under text cursor
BUSY_COUNTER    =$8080  ; Counter for busy indicator
BUSY_BITMAP     =$8081  ; Bitmap for busy indicator
OP1             =$8082  ; TI Homescreen OP1 Register (11 bytes)
OP2             =$808D  ; TI Homescreen OP2 Register (11 bytes)
OP3             =$8098  ; TI Homescreen OP3 Register (11 bytes)
OP4             =$80A3  ; TI Homescreen OP4 Register (11 bytes)
OP5             =$80AE  ; TI Homescreen OP5 Register (11 bytes)
OP6             =$80B9  ; TI Homescreen OP6 Register (11 bytes)
CURR_INPUT      =$80C6  ; Pointer to current Homescreen input
BYTES_USED      =$80CC  ; Number of used user memory (Add to 80C8 to find
                        ; first byte of free memory)
TEXT_MEM        =$80DF  ; Text Memory Area (168 bytes)
CHECKSUM        =$81BE  ; Memory checksum from 8BF7 to FA6F
CURSOR_X        =$8333  ; X value of menu text cursor
CURSOR_Y        =$8334  ; Y value of menu text cursor
_IY_TABLE       =$8346  ; Where IY usually points
GRAPH_MEM       =$8641  ; Graphics Memory Area (1024 bytes)
TEXT_MEM2       =$8A6B  ; Secondary Text Memory
USER_MEM        =$8B1B  ; Pointer to start of User memory
SCROLL_START    =$8B2F  ; First row of screen scrolling window (0-7)
SCROLL_END      =$8B30  ; Last row of screen scrolling window (1-8)
FIXED_POINT     =$8B3A  ; Fixed-point decimal place (FFh for floating point)
VAT_END         =$8BEB  ; Pointer one byte before end of VAT (backwards)
VAT_START       =$FA6F  ; Start of VAT
VIDEO_MEM       =$FC00  ; Video Memory Area (1024 bytes)

;
; Key Scancode definitions
;
;                      Function               Character
K_NOKEY       =$00   ; No key
K_DOWN        =$01   ; Down
K_LEFT        =$02   ; Left
K_RIGHT       =$03   ; Right
K_UP          =$04   ; Up
K_ENTER       =$09   ; Enter
K_PLUS        =$0A   ; +                      X
K_MINUS       =$0B   ; -                      T
K_STAR        =$0C   ; *                      O
K_SLASH       =$0D   ; /                      J
K_RAISE       =$0E   ; ^                      E
K_CLEAR       =$0F   ; Clear
K_SIGN        =$11   ; (-)                    Space
K_3           =$12   ; 3                      W
K_6           =$13   ; 6                      S
K_9           =$14   ; 9                      N
K_RIGHTPAR    =$15   ; )                      I
K_TAN         =$16   ; Tan                    D
K_CUSTOM      =$17   ; Custom
K_DOT         =$19   ; .                      Z
K_2           =$1A   ; 2                      V
K_5           =$1B   ; 5                      R
K_8           =$1C   ; 8                      M
K_LEFTPAR     =$1D   ; (                      H
K_COS         =$1E   ; Cos                    C
K_PRGM        =$1F   ; Prgm
K_DEL         =$20   ; Del
K_0           =$21   ; 0                      Y
K_1           =$22   ; 1                      U
K_4           =$23   ; 4                      Q
K_7           =$24   ; 7                      L
K_EE          =$25   ; EE                     G
K_SIN         =$26   ; Sin                    B
K_STAT        =$27   ; Stat
K_XVAR        =$28   ; x-Var                  x
K_ON          =$29   ; On
K_STO         =$2A   ; Sto                    =
K_COMMA       =$2B   ; ,                      P
K_SQUARE      =$2C   ; x^2                    K
K_LN          =$2D   ; Ln                     F
K_LOG         =$2E   ; Log                    A
K_GRAPH       =$2F   ; Graph
K_ALPHA       =$30   ; Alpha
K_F5          =$31   ; F5
K_F4          =$32   ; F4
K_F3          =$33   ; F3
K_F2          =$34   ; F2
K_F1          =$35   ; F1
K_SECOND      =$36   ; 2nd
K_EXIT        =$37   ; EXIT
K_MORE        =$38   ; MORE
